############################################################
#                                                          #
#              Temporal variations                         #
#                                                          #
############################################################
#-------------------------------------------------------------------------------
# Plot per la mitjana de totes les estacions:

#First, we create a matrix to put the data of observations and model (corrected and raw)
obs_total          <- matrix(nrow = length(length_loop), ncol = 0) 
raw_model_total    <- matrix(nrow = length(length_loop), ncol = 0)
UK_model_total     <- matrix(nrow = length(length_loop), ncol = 0)


for (station_code in names_local_stations) {
  
  if (station_code %in% colnames(df_obs_sub)) {obs_station <- df_obs_sub[ ,station_code]}
  else {obs_station <- NA}  

  obs_total        <- cbind(obs_total,obs_station)
  raw_model_total  <- cbind(raw_model_total,model_raw_at_AQMS_df[ ,station_code])
  UK_model_total   <- cbind(UK_model_total,LOOCV_total_df[ ,station_code])
}

#Then, we calculate the means of each hour considering the whole stations
raw_model <- data.frame( obs = rowMeans(obs_total,na.rm=TRUE),
                         mod = rowMeans(raw_model_total,na.rm=TRUE),
                         model="raw_model")

UK_model <- data.frame(   obs = rowMeans(obs_total,na.rm=TRUE),
                          mod = rowMeans(UK_model_total,na.rm=TRUE),
                          model="corr_model")


Mean_all_stations            <- data.frame(date            = df_obs_sub$date,
                                           observations       = raw_model$obs,
                                           raw_Model          = raw_model$mod, 
                                           UK_Model           = UK_model$mod)

TIME_VAR <- openair::timeVariation(Mean_all_stations,
                                   pollutant = c("observations","raw_Model","UK_Model"),
                                   ylab = paste0(pollutant, " ", "(ug/m3)"),
                                   type ="month",
                                   key = TRUE,
                                   title = "Media horaria Cat",
                                   auto.text=FALSE,
                                   ci = FALSE,
                                   conf.int = c(0.75, 0.99),
                                   ylim = c(0, limit),
                                   cols = c("black", "blue", "grey"),
                                   lty = c("dotted","solid","dashed"),
                                   lwd = c(3,2,2), 
                                   name.pol = c("Observations", "Raw model", "UK Model"))

png(file = paste0(save_general_statistics,"temporal_",pollutant,"_mean_time_VAR.png"), width = 800, height = 600)
print(TIME_VAR[[1]][2]) 
dev.off()
#-------------------------------------------------------------------------------
# Plot per cada estació:


for (station_code in names_local_stations) {
  
  # station_code <- names_local_stations[[1]]
  if (station_code %in% colnames(df_obs_sub)) {obs_station <- df_obs_sub[ ,station_code]
  } else {obs_station <- NA}  
  obs_estacio         <-  obs_station
  raw_model_estacio   <-  model_raw_at_AQMS_df[ ,station_code]
  UK_model_estacio    <-  LOOCV_total_df[ ,station_code]

  
  Single_station            <- data.frame(date               = df_obs_sub$date,
                                          observations       = obs_estacio,
                                          raw_Model          = raw_model_estacio, 
                                          UK_corrected       = UK_model_estacio)
                                          
  
  TIME_VAR <- openair::timeVariation(Single_station,
                                     pollutant = c("observations","raw_Model","UK_corrected"),
                                     ylab = paste0(pollutant, " ", "(ug/m3)"),
                                     type ="month",
                                     key = TRUE,
                                     title = station_code,
                                     auto.text=FALSE, 
                                     ci = FALSE,
                                     conf.int = c(0.75, 0.99),
                                     ylim = c(0, limit),
                                     cols = c("black", "blue", "grey"),
                                     lty = c("dotted","solid","dashed"),
                                     lwd = c(3,2,2),
                                     name.pol = c("Observations", "Raw model", "UK Model"))  
  png(file = paste0(save_temporal_variation,station_code,"_",pollutant,"_time_VAR.png"), width = 800, height = 600)
  print(TIME_VAR[[1]][2]) 
  dev.off()
  
}

